// Constants
var WIDGET_VERSION = "1.2";

// Global Variables
var lastUpdated = 0;                  // Track last refresh time to avoid excessive updates
var httpRequest = null;               // The current XMLHttpRequest

//
// Function: load()
// Called by HTML body element's onload event when the widget is ready to start
//
function load()
{
    setupParts();
}

//
// Function: remove()
// Called when the widget has been removed from the Dashboard
//
function remove()
{
    // Stop any timers to prevent CPU usage
    // Remove any preferences as needed
    // widget.setPreferenceForKey(null, createInstancePreferenceKey("your-key"));
}

//
// Function: hide()
// Called when the widget has been hidden
//
function hide()
{
    // Stop any timers to prevent CPU usage
}

//
// Function: hideElement(elementId)
// Turn off display for the given element.
//
// elementId: DOM id of the element to hide.
//
function hideElement(elementId)
{
    var element = document.getElementById(elementId);
    if (element)
        element.style.display = "none";
}

//
// Function: showElement(elementId)
// Turn on display for the given element.
//
// elementId: DOM id of the element to show.
//
function showElement(elementId)
{
    var element = document.getElementById(elementId);
    if (element)
        element.style.display = "block";
}

//
// Function: refreshFreebies()
// Starts loading the html source.
// processDocument() will be called when it finishes loading.
//
function refreshFreebies()
{
    showElement("loading-text");

    // Abort any pending request before starting a new one
    if (httpRequest != null) {
        httpRequest.abort();
        httpRequest = null;
    }
    httpRequest = new XMLHttpRequest();

    // Function callback when feed is loaded
    httpRequest.onload = function (e)
    {
        var html;
        if (httpRequest.responseText) html = httpRequest.responseText;

        // Request is no longer pending
        httpRequest = null;

        // Process the loaded document
        processHtml(html);
    }
    httpRequest.open("GET", 'http://itunes.appspot.com/static/us/dashboard_widget_content.html');
    httpRequest.setRequestHeader("Cache-Control", "no-cache");

    // Send the request asynchronously
    httpRequest.send(null);
}

function openMarketWall()
{
	widget.openURL('http://marketwall.com/');
}

function openMarketWallContact()
{
	widget.openURL('http://marketwall.com/tickets/new');
}

function checkForUpdates()
{
    widget.openURL('http://marketwall.com/itunes_freebies/widget_update?version=' + WIDGET_VERSION);
}

//
// Function: refreshScrollArea()
// Updates the content areas's scroll bar when the content or article length has changed.
//
function refreshScrollArea()
{
    var contentarea = document.getElementById("scrollArea");
    if (contentarea) contentarea.object.refresh();
}

//
// Function: processHtml(doc)
// When the feed finishes loading, this function is called to parse it and display the results.
//
// doc: XML document containing the feed
//
function processHtml(html)
{
    hideElement("loading-text");
	
    if (html) {

        // Generate the display
		document.getElementById("content").innerHTML = html;

        // set lastUpdated to the current time to keep track of the last time a request was posted
        lastUpdated = (new Date).getTime();
    }
    else {
        // document is empty
		document.getElementById("content").innerHTML = 
			getLocalizedString('Unable to load data.  Check your internet connection. If the problem continues, please report it to us at <a href="#" onclick="openMarketWallContact(event)">http://marketwall.com/tickets/new</a>');
    }
	
	// update the scrollbar so scrollbar matches new data
    refreshScrollArea();
}

//
// Function: show()
// Called when the widget has been shown
//
function show()
{
    // Refresh feed if 3 hours have passed since the last update
    var now = (new Date).getTime();
    if ((now - lastUpdated) > 3 * 60 * 60 * 1000) {
        refreshFreebies();
    }
}

//
// Function: sync()
// Called when the widget has been synchronized with .Mac
//
function sync()
{
    // Retrieve any preference values that you need to be synchronized here
    // Use this for an instance key's value:
    // instancePreferenceValue = widget.preferenceForKey(null, createInstancePreferenceKey("your-key"));
    //
    // Or this for global key's value:
    // globalPreferenceValue = widget.preferenceForKey(null, "your-key");
}

//
// Function: showBack(event)
// Called when the info button is clicked to show the back of the widget
//
// event: onClick event from the info button
//
function showBack(event)
{
    var front = document.getElementById("front");
    var back = document.getElementById("back");

    if (window.widget) {
        widget.prepareForTransition("ToBack");
    }

    front.style.display = "none";
    back.style.display = "block";

    if (window.widget) {
        setTimeout('widget.performTransition();', 0);
    }
}

//
// Function: showFront(event)
// Called when the done button is clicked from the back of the widget
//
// event: onClick event from the done button
//
function showFront(event)
{
    var front = document.getElementById("front");
    var back = document.getElementById("back");

    if (window.widget) {
        widget.prepareForTransition("ToFront");
    }

    front.style.display="block";
    back.style.display="none";

    if (window.widget) {
        setTimeout('widget.performTransition();', 0);
    }
}

if (window.widget) {
    widget.onremove = remove;
    widget.onhide = hide;
    widget.onshow = show;
    widget.onsync = sync;
}
